ResizerImageImpl class

Implemented types

Constructors

ResizerImageImpl(ExternalLibrary dylib)
factory
ResizerImageImpl.raw(ResizerImagePlatform _platform)
ResizerImageImpl.wasm(FutureOr<WasmModule> module)
Only valid on web/WASM platforms.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
kResizerConstMeta → FlutterRustBridgeTaskConstMeta
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resizer({required String image, required int width, required int height, required int percent, dynamic hint}) → Future<Uint8List>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited